# Global Power Plant Database

The Global Power Plant Database is a comprehensive, open source database of power plants around the world [datasets.wri.org](https://datasets.wri.org/datasets/global-power-plant-database).

💾 [global-power-plant-database-v2](https://kamangir-public.s3.ca-central-1.amazonaws.com/global-power-plant-database-v2.tar.gz)

 - dataset: https://datasets.wri.org/datasets/global-power-plant-database
 - metadata: https://datasets.wri.org/api/3/action/resource_show?id=66bcdacc-3d0e-46ad-9271-a5a76b1853d2
 - research: https://www.wri.org/research/global-database-power-plants

| ![image](https://github.com/kamangir/assets/blob/main/blue-geo/global_power_plant_database-1.png?raw=true) | ![image](https://github.com/kamangir/assets/blob/main/blue-geo/global_power_plant_database-2.png?raw=true) |
|---|---|
